===========================
Salt 2014.7.6 Release Notes
===========================

:release: TBA

Version 2014.7.6 is a bugfix release for :doc:`2014.7.0
</topics/releases/2014.7.0>`.

Changes:

- salt.runners.cloud.action() has changed the `fun` keyword argument to `func`.
  Please update any calls to this function in the cloud runner.
